==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/Zapomoga.java <==
package pl.topteam.dps.model.main_gen;

import java.math.BigDecimal;
import java.util.Date;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class Zapomoga extends GenericDPSObject {
    /**
     * ZAPOMOGA.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * ZAPOMOGA.EWIDENCJA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long ewidencjaId;

    /**
     * ZAPOMOGA.RODZAJ_ZAPOMOGI_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long rodzajZapomogiId;

    /**
     * ZAPOMOGA.DATA_UDZIELENIA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date dataUdzielenia;

    /**
     * ZAPOMOGA.KWOTA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private BigDecimal kwota;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return ZAPOMOGA.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * ZAPOMOGA.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return ZAPOMOGA.EWIDENCJA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getEwidencjaId() {
        return ewidencjaId;
    }

    /**
     * ZAPOMOGA.EWIDENCJA_ID
     *
     * @param ewidencjaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setEwidencjaId(Long ewidencjaId) {
        this.ewidencjaId = ewidencjaId;
    }

    /**
     * @return ZAPOMOGA.RODZAJ_ZAPOMOGI_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getRodzajZapomogiId() {
        return rodzajZapomogiId;
    }

    /**
     * ZAPOMOGA.RODZAJ_ZAPOMOGI_ID
     *
     * @param rodzajZapomogiId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setRodzajZapomogiId(Long rodzajZapomogiId) {
        this.rodzajZapomogiId = rodzajZapomogiId;
    }

    /**
     * @return ZAPOMOGA.DATA_UDZIELENIA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getDataUdzielenia() {
        return dataUdzielenia;
    }

    /**
     * ZAPOMOGA.DATA_UDZIELENIA
     *
     * @param dataUdzielenia
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDataUdzielenia(Date dataUdzielenia) {
        this.dataUdzielenia = dataUdzielenia;
    }

    /**
     * @return ZAPOMOGA.KWOTA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public BigDecimal getKwota() {
        return kwota;
    }

    /**
     * ZAPOMOGA.KWOTA
     *
     * @param kwota
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setKwota(BigDecimal kwota) {
        this.kwota = kwota;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        Zapomoga other = (Zapomoga) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getEwidencjaId() == null ? other.getEwidencjaId() == null : this.getEwidencjaId().equals(other.getEwidencjaId()))
            && (this.getRodzajZapomogiId() == null ? other.getRodzajZapomogiId() == null : this.getRodzajZapomogiId().equals(other.getRodzajZapomogiId()))
            && (this.getDataUdzielenia() == null ? other.getDataUdzielenia() == null : this.getDataUdzielenia().equals(other.getDataUdzielenia()))
            && (this.getKwota() == null ? other.getKwota() == null : this.getKwota().equals(other.getKwota()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getEwidencjaId() == null) ? 0 : getEwidencjaId().hashCode());
        result = prime * result + ((getRodzajZapomogiId() == null) ? 0 : getRodzajZapomogiId().hashCode());
        result = prime * result + ((getDataUdzielenia() == null) ? 0 : getDataUdzielenia().hashCode());
        result = prime * result + ((getKwota() == null) ? 0 : getKwota().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", ewidencjaId=").append(ewidencjaId);
        sb.append(", rodzajZapomogiId=").append(rodzajZapomogiId);
        sb.append(", dataUdzielenia=").append(dataUdzielenia);
        sb.append(", kwota=").append(kwota);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/Zapomoga.java <==
package pl.topteam.dps.model.main_gen;

import java.math.BigDecimal;
import java.util.Date;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class Zapomoga extends GenericDPSObject {
    /**
     * ZAPOMOGA.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * ZAPOMOGA.EWIDENCJA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long ewidencjaId;

    /**
     * ZAPOMOGA.RODZAJ_ZAPOMOGI_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long rodzajZapomogiId;

    /**
     * ZAPOMOGA.DATA_UDZIELENIA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date dataUdzielenia;

    /**
     * ZAPOMOGA.KWOTA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private BigDecimal kwota;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return ZAPOMOGA.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * ZAPOMOGA.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return ZAPOMOGA.EWIDENCJA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getEwidencjaId() {
        return ewidencjaId;
    }

    /**
     * ZAPOMOGA.EWIDENCJA_ID
     *
     * @param ewidencjaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setEwidencjaId(Long ewidencjaId) {
        this.ewidencjaId = ewidencjaId;
    }

    /**
     * @return ZAPOMOGA.RODZAJ_ZAPOMOGI_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getRodzajZapomogiId() {
        return rodzajZapomogiId;
    }

    /**
     * ZAPOMOGA.RODZAJ_ZAPOMOGI_ID
     *
     * @param rodzajZapomogiId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setRodzajZapomogiId(Long rodzajZapomogiId) {
        this.rodzajZapomogiId = rodzajZapomogiId;
    }

    /**
     * @return ZAPOMOGA.DATA_UDZIELENIA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getDataUdzielenia() {
        return dataUdzielenia;
    }

    /**
     * ZAPOMOGA.DATA_UDZIELENIA
     *
     * @param dataUdzielenia
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDataUdzielenia(Date dataUdzielenia) {
        this.dataUdzielenia = dataUdzielenia;
    }

    /**
     * @return ZAPOMOGA.KWOTA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public BigDecimal getKwota() {
        return kwota;
    }

    /**
     * ZAPOMOGA.KWOTA
     *
     * @param kwota
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setKwota(BigDecimal kwota) {
        this.kwota = kwota;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        Zapomoga other = (Zapomoga) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getEwidencjaId() == null ? other.getEwidencjaId() == null : this.getEwidencjaId().equals(other.getEwidencjaId()))
            && (this.getRodzajZapomogiId() == null ? other.getRodzajZapomogiId() == null : this.getRodzajZapomogiId().equals(other.getRodzajZapomogiId()))
            && (this.getDataUdzielenia() == null ? other.getDataUdzielenia() == null : this.getDataUdzielenia().equals(other.getDataUdzielenia()))
            && (this.getKwota() == null ? other.getKwota() == null : this.getKwota().equals(other.getKwota()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getEwidencjaId() == null) ? 0 : getEwidencjaId().hashCode());
        result = prime * result + ((getRodzajZapomogiId() == null) ? 0 : getRodzajZapomogiId().hashCode());
        result = prime * result + ((getDataUdzielenia() == null) ? 0 : getDataUdzielenia().hashCode());
        result = prime * result + ((getKwota() == null) ? 0 : getKwota().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", ewidencjaId=").append(ewidencjaId);
        sb.append(", rodzajZapomogiId=").append(rodzajZapomogiId);
        sb.append(", dataUdzielenia=").append(dataUdzielenia);
        sb.append(", kwota=").append(kwota);
        sb.append("]");
        return sb.toString();
    }
}
